@@ -1,8 +1,7 @@
-import sys
-assert sys.version_info[0] == 3, "This program requires Python 3"
-
 import re
+import sys
 from doctest import testfile
+from glob import glob
 from io import StringIO
 
 import bitarray.util
@@ -11,39 +10,54 @@ import bitarray.util
 BASE_URL = "https://github.com/ilanschnell/bitarray"
 
 NEW_IN = {
-    'bitarray':               '2.3: optional `buffer` argument',
+    'bitarray':              ['2.3: optional `buffer` argument',
+                              '3.4: allow initializer `bytes` or `bytearray` '
+                                   'to set buffer directly'],
     'bitarray.bytereverse':   '2.2.5: optional start and stop arguments',
     'bitarray.clear':         '1.4',
     'bitarray.count':        ['1.1.0: optional start and stop arguments',
                               '2.3.7: optional step argument',
                               '2.9: add non-overlapping sub-bitarray count'],
+    'bitarray.decode':        '3.0: returns iterator (equivalent to past '
+                                   '`.iterdecode()`)',
+    'bitarray.endian':        '3.4: replaces former `.endian()` method',
+    'bitarray.extend':        '3.4: allow `bytes` object',
     'bitarray.find':         ['2.1',
                               '2.9: add optional keyword argument `right`'],
     'bitarray.frombytes':     '2.5.0: allow bytes-like argument',
     'bitarray.index':        ['2.9: add optional keyword argument `right`'],
-    'bitarray.itersearch':   ['2.9: optional start and stop arguments - '
-                              'add optional keyword argument `right`'],
     'bitarray.invert':        '1.5.3: optional index argument',
     'bitarray.pack':          '2.5.0: allow bytes-like argument',
+    'bitarray.search':       ['2.9: optional start and stop arguments - '
+                                   'add optional keyword argument `right`',
+                              '3.0: returns iterator (equivalent to past '
+                                   '`.itersearch()`)'],
+    'bitarray.to01':          '3.3: optional `group` and `sep` arguments',
     'decodetree':             '1.6',
     'frozenbitarray':         '1.1',
     'get_default_endian':     '1.3',
     'util.any_and':           '2.7',
-    'util.ba2base':           '1.9',
-    'util.base2ba':           '1.9',
+    'util.byteswap':          '3.4',
+    'util.ba2base':          ['1.9',
+                              '3.3: optional `group` and `sep` arguments'],
+    'util.base2ba':          ['1.9',
+                              '3.3: ignore whitespace'],
+    'util.ba2hex':            '3.3: optional `group` and `sep` arguments',
+    'util.hex2ba':            '3.3: ignore whitespace',
+    'util.correspond_all':    '3.4',
     'util.count_n':           '2.3.6: optional value argument',
     'util.deserialize':      ['1.8',
                               '2.5.0: allow bytes-like argument'],
     'util.intervals':         '2.7',
-    'util.make_endian':      ['1.3',
-                              '2.9: deprecated - use `bitarray()`'],
     'util.ones':              '2.9',
     'util.parity':            '1.9',
+    'util.sum_indices':       '3.6',
+    'util.xor_indices':       '3.2',
     'util.pprint':            '1.8',
-    'util.rindex':           ['2.3.0: optional start and stop arguments',
-                              '2.9: deprecated - use `.index(..., right=1)`'],
     'util.serialize':         '1.8',
     'util.urandom':           '1.7',
+    'util.random_k':          '3.6',
+    'util.random_p':          '3.5',
     'util.sc_encode':         '2.7',
     'util.sc_decode':         '2.7',
     'util.vl_decode':         '2.2',
@@ -53,18 +67,23 @@ NEW_IN = {
 }
 
 DOCS = {
+    'ba3': ('Bitarray 3 transition', 'bitarray3.rst'),
     'chc': ('Canonical Huffman Coding', 'canonical.rst'),
     'rep': ('Bitarray representations', 'represent.rst'),
+    'rnd': ('Random Bitarrays', 'random_p.rst'),
     'sc':  ('Compression of sparse bitarrays', 'sparse_compression.rst'),
     'vlf': ('Variable length bitarray format', 'variable_length.rst'),
 }
 
 DOC_LINKS = {
+    'bitarray.decode':         'ba3',
+    'bitarray.search':         'ba3',
     'util.canonical_huffman':  'chc',
     'util.canonical_decode':   'chc',
     'util.ba2base':            'rep',
     'util.base2ba':            'rep',
     'util.deserialize':        'rep',
+    'util.random_p':           'rnd',
     'util.serialize':          'rep',
     'util.sc_decode':          'sc',
     'util.sc_encode':          'sc',
@@ -87,6 +106,7 @@ NOTES = {
 }
 
 GETSET = {
+    'bitarray.endian':     'str',
     'bitarray.nbytes':     'int',
     'bitarray.padbits':    'int',
     'bitarray.readonly':   'bool',
@@ -120,7 +140,7 @@ def get_doc(name):
     if m is None:
         raise Exception("signature invalid: %r" % lines[0])
     sig = '``%s``' %  m.group(1)
-    assert m.group(2) == obj.__name__
+    assert m.group(2) == obj.__name__, lines[0]
     if m.group(4):
         sig += ' -> %s' % m.group(4)
     assert lines[1] == ''
@@ -148,7 +168,7 @@ def write_doc(fo, name):
     new_in = NEW_IN.get(name)
     if new_in:
         for line in new_in if isinstance(new_in, list) else [new_in]:
-            fo.write("\n   New in version %s.\n" % line.replace('`', '``'))
+            fo.write("\n   New in version %s\n" % line.replace('`', '``'))
 
     fo.write('\n\n')
 
@@ -202,7 +222,7 @@ The bitarray object:
     fo.write("Functions defined in `bitarray.util` module:\n"
              "--------------------------------------------\n\n"
              "This sub-module was added in version 1.2.\n\n")
-    for func in bitarray.util.__all__:
+    for func in sorted(bitarray.util.__all__):
         write_doc(fo, 'util.%s' % func)
 
     for name in list(NEW_IN) + list(DOC_LINKS):
@@ -276,12 +296,8 @@ def main():
         write_changelog(fo)
 
     testfile('./README.rst')
-    testfile('./doc/buffer.rst')
-    testfile('./doc/canonical.rst')
-    testfile('./doc/indexing.rst')
-    testfile('./doc/represent.rst')
-    testfile('./doc/sparse_compression.rst')
-    testfile('./doc/variable_length.rst')
+    for path in glob("./doc/*.rst"):
+        testfile(path)
 
 
 if __name__ == '__main__':
